==> mctq_0.3.1.tar.gz: mctq/tests/testthat.R <==
library(checkmate)
library(mctq)
library(testthat)

test_check("mctq")

# # For development use only (comment the code after use (Ctrl + Shift + C)).
#
# .rs.restartR()
# BiocCheck::BiocCheck()
# cffr::cff_write()
# codemetar::write_codemeta()
# covr::package_coverage()
# devtools::check()
# devtools::check(remote = TRUE, manual = TRUE)
# devtools::check_mac_release()
# devtools::check_rhub()
# devtools::check_rhub(platforms = c(
#     "windows-x86_64-devel", "windows-x86_64-release",
#     "macos-highsierra-release-cran", "ubuntu-gcc-devel",
#     "ubuntu-gcc-release", "debian-clang-devel", "debian-gcc-release",
#     "fedora-clang-devel", "solaris-x86-patched"
# ))
# devtools::check_win_devel()
# devtools::check_win_release()
# devtools::check_win_oldrelease()
# devtools::document()
# devtools::install()
# devtools::release()
# devtools:test()
# dlstats::cran_stats(c("mctq", "nparACT"))
# goodpractice::gp()
# normalizePath(readClipboard(), "/", mustWork = FALSE)
# template <- list(package = "rotemplate")
# pkgdown::build_article("mctq", override = list(template = template))
# pkgdown::build_favicons(overwrite = TRUE)
# pkgdown::build_reference(override = list(template = template))
# pkgdown::build_site(devel = FALSE, override = list(template = template))
# revdepcheck::revdep_check(num_workers = 4)
# spelling::spell_check_package()
# spelling::update_wordlist()
# urlchecker::url_check()
# usethis::use_coverage()
# usethis::use_dev_version()
# usethis::use_github_action("check-pak")
# usethis::use_github_action("test-coverage-pak")
# usethis::use_logo(file.choose())
# usethis::use_release_issue("#.#.#")
# usethis::use_dev_version()
# usethis::use_revdep()
# usethis::use_tidy_description()
# usethis::use_version()

==> mctq_0.3.2.tar.gz: mctq/tests/testthat.R <==
library(checkmate)
library(hms)
library(lubridate)
library(mctq)
library(mockr)
library(rlang)
library(testthat)

testthat::test_check("mctq")

# # For development use only (comment the code after use (Ctrl + Shift + C)).
#
# .rs.restartR()
# BiocCheck::BiocCheck()
# cffr::cff_write()
# codemetar::write_codemeta()
# covr::package_coverage()
# devtools::check()
# devtools::check(remote = TRUE, manual = TRUE)
# devtools::check_rhub()
# rhub::platforms()
# rversions::r_oldrel()
# devtools::check_rhub(platforms = c(
#     "windows-x86_64-devel", "windows-x86_64-release",
#     "windows-x86_64-oldrel", "macos-highsierra-release-cran", 
#     "ubuntu-gcc-devel", "ubuntu-gcc-release"
# ))
# devtools::check_win_devel()
# devtools::check_win_release()
# devtools::check_win_oldrelease()
# devtools::check_mac_release()
# devtools::document()
# devtools::install()
# devtools::release()
# devtools::submit_cran()
# devtools:test()
# dlstats::cran_stats(c("mctq", "nparACT"))
# goodpractice::gp()
# normalizePath(readClipboard(), "/", mustWork = FALSE)
# template <- list(package = "rotemplate")
# pkgdown::build_article("mctq", override = list(template = template))
# pkgdown::build_favicons(overwrite = TRUE)
# pkgdown::build_reference(override = list(template = template))
# pkgdown::build_site(devel = FALSE, override = list(template = template))
# revdepcheck::revdep_check(num_workers = 4)
# spelling::spell_check_package()
# spelling::update_wordlist()
# urlchecker::url_check()
# usethis::use_coverage()
# usethis::use_dev_version()
# usethis::use_github_action("check-pak")
# usethis::use_github_action("test-coverage-pak")
# usethis::use_logo(file.choose())
# usethis::use_release_issue("#.#.#")
# usethis::use_dev_version()
# usethis::use_revdep()
# usethis::use_tidy_description()
# usethis::use_version()
